@@ -27,8 +27,8 @@ cd "${SCRATCH}/${BUILD_TAG}.gnu"
 
 cmake \
     -DCMAKE_SYSTEM_NAME=CrayLinuxEnvironment \
+    -DCMAKE_CROSSCOMPILING_EMULATOR="" \
     -DUSE_CUDA=ON \
-    -DUSE_CUBLAS=ON \
     -DWITH_GPU=P100 \
     -DBLAS_FOUND=ON -DBLAS_LIBRARIES="-lsci_gnu_mpi_mp" \
     -DLAPACK_FOUND=ON -DLAPACK_LIBRARIES="-lsci_gnu_mpi_mp" \
