@@ -8,6 +8,7 @@ import numpy
 
 try:
     from Cython.Build import cythonize
+
     USE_CYTHON = True
     EXT = "pyx"
 except ImportError:
@@ -16,13 +17,12 @@ except ImportError:
     cythonize = lambda ext: ext
 
 extensions = [
-    Extension("cp2k", ["cp2k.{}".format(EXT)],
+    Extension(
+        "cp2k",
+        ["cp2k.{}".format(EXT)],
         include_dirs=[numpy.get_include()],
         libraries=["cp2k"],
-        ),
+    ),
 ]
 
-setup(
-    name="cp2k",
-    ext_modules=cythonize(extensions)
-)
+setup(name="cp2k", ext_modules=cythonize(extensions))
