@@ -1,14 +1,12 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
+#!/usr/bin/env python3
 
 # author: Ole Schuett
 
-from __future__ import print_function
-
 import argparse
 import re
 import ast
 from os import path
+from argparse import RawTextHelpFormatter  # enable newline
 
 blas_re = re.compile(
     r"[SDCZ]"
@@ -31,12 +29,13 @@ lapack_re = re.compile(
 )
 
 warning_re = re.compile(r".*[Ww]arning: (.*)")
-warning_re_subst = re.compile(r"'\d+'")  # replace occurences of '49' with *
 
 IGNORED_WARNINGS = (
     "-Wrealloc-lhs",
     "-Wdo-subscript",
+    "-Winteger-division",
     "-Wmaybe-uninitialized",
+    "-Wfunction-elimination",
     "Creating array temporary",
     "quality comparison",
     "defined but not used",
@@ -82,7 +81,8 @@ def check_warnings(fhandle):
             continue  # we are only looking for warnings
         warning = m.group(1)
 
-        warning = warning_re_subst.sub("*", warning)
+        warning = re.sub(r"[‘’]", "'", warning)  # replace unicode apostrophes
+        warning = re.sub(r"'\d+'", "*", warning)  # replace numbers with *
 
         if any(iw in warning for iw in IGNORED_WARNINGS):
             continue
@@ -122,7 +122,7 @@ def may_call_implicit(loc, routine):
 
     pkg = path.dirname(loc)
     manifest_fn = pkg + "/PACKAGE"
-    with open(manifest_fn) as fhandle:
+    with open(manifest_fn, encoding="utf8") as fhandle:
         manifest = ast.literal_eval(fhandle.read())
 
     if "implicit" not in manifest:
@@ -137,9 +137,10 @@ if __name__ == "__main__":
         epilog="""\
 For generating the warn-files run gfortran with all warning flags and redirect the output to a file.
 This can be achieved by putting
-    FCLOGPIPE = 2>$(notdir $<).warn
+    FCLOGPIPE   = 2>&1 | tee $(notdir $<).warn
 in the cp2k arch-file.
 """,
+        formatter_class=RawTextHelpFormatter,
     )
     parser.add_argument(
         "files",
@@ -151,5 +152,5 @@ in the cp2k arch-file.
     args = parser.parse_args()
 
     for fn in args.files:
-        with open(fn) as fhandle:
+        with open(fn, encoding="utf8") as fhandle:
             check_warnings(fhandle)
