@@ -1,10 +1,7 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
+#!/usr/bin/env python3
 
 # author: Ole Schuett
 
-from __future__ import print_function
-
 import argparse
 import re
 import sys
@@ -13,29 +10,37 @@ from os import path
 from datetime import datetime
 
 flag_exceptions_re = re.compile(
-    r"__COMPILE_REVISION|__COMPILE_DATE|__COMPILE_ARCH|__COMPILE_HOST|"
-    r"__INTEL_COMPILER|__cplusplus|\$\{.*\}\$|__.*__"
+    r"__COMPILE_REVISION|__COMPILE_DATE|__COMPILE_ARCH|__COMPILE_HOST|CUDA_VERSION|"
+    r"__INTEL_COMPILER|__cplusplus|_OPENMP|\$\{.*\}\$|__.*__"
 )
 
+portable_filename_re = re.compile(r"^[a-zA-Z0-9._/#~=+-]*$")
+
 BANNER_F = """\
 !--------------------------------------------------------------------------------------------------!
 !   CP2K: A general program to perform molecular dynamics simulations                              !
-!   Copyright (C) 2000 - {:4}  CP2K developers group                                               !
+!   Copyright 2000-{:d} CP2K developers group <https://cp2k.org>                                   !
+!                                                                                                  !
+!   SPDX-License-Identifier: GPL-2.0-or-later                                                      !
 !--------------------------------------------------------------------------------------------------!
 """
 
 BANNER_Fypp = """\
 #!-------------------------------------------------------------------------------------------------!
 #!   CP2K: A general program to perform molecular dynamics simulations                             !
-#!   Copyright (C) 2000 - {:4}  CP2K developers group                                              !
+#!   Copyright 2000-{:d} CP2K developers group <https://cp2k.org>                                  !
+#!                                                                                                 !
+#!   SPDX-License-Identifier: GPL-2.0-or-later                                                     !
 #!-------------------------------------------------------------------------------------------------!
 """
 
 BANNER_C = """\
-/*****************************************************************************
- *  CP2K: A general program to perform molecular dynamics simulations        *
- *  Copyright (C) 2000 - {:d}  CP2K developers group                         *
- *****************************************************************************/
+/*----------------------------------------------------------------------------*/
+/*  CP2K: A general program to perform molecular dynamics simulations         */
+/*  Copyright 2000-{:d} CP2K developers group <https://cp2k.org>              */
+/*                                                                            */
+/*  SPDX-License-Identifier: GPL-2.0-or-later                                 */
+/*----------------------------------------------------------------------------*/
 """
 
 DEFAULT_EXCLUDED_DIRS = (
@@ -71,7 +76,7 @@ def validate(cp2k_dir, filelist=None, excluded_dirs=DEFAULT_EXCLUDED_DIRS):
 
     # also exclude any Git submodules
     if path.exists(path.join(cp2k_dir, ".gitmodules")):
-        with open(path.join(cp2k_dir, ".gitmodules"), "r") as fhandle:
+        with open(path.join(cp2k_dir, ".gitmodules"), encoding="utf8") as fhandle:
             excluded_dirs += [
                 path.join(cp2k_dir, l.split()[-1]) for l in fhandle if "path =" in l
             ]
@@ -94,7 +99,7 @@ def validate(cp2k_dir, filelist=None, excluded_dirs=DEFAULT_EXCLUDED_DIRS):
             if fn_ext in ("template", "instantiate"):
                 continue
 
-            with open(path.join(root, fn)) as fhandle:
+            with open(path.join(root, fn), encoding="utf8") as fhandle:
                 content = fhandle.read()
 
             # check banner
@@ -112,15 +117,16 @@ def validate(cp2k_dir, filelist=None, excluded_dirs=DEFAULT_EXCLUDED_DIRS):
                 warnings += ["%s: Copyright banner malformed" % fn]
 
             # find all flags
+            line_continuation = False
             for line in content.split("\n"):
-                if len(line) == 0:
-                    continue
-                if line[0] != "#":
-                    continue
-                if line.split()[0] not in ("#if", "#ifdef", "#ifndef", "#elif"):
-                    continue
+                if not line_continuation:
+                    if len(line) == 0 or line[0] != "#":
+                        continue
+                    if line.split()[0] not in ("#if", "#ifdef", "#ifndef", "#elif"):
+                        continue
                 line = line.split("//", 1)[0]
-                line = re.sub("[|()!&><=*/+-]", " ", line)
+                line_continuation = line.strip().endswith("\\")
+                line = re.sub(r"[\\|()!&><=*/+-]", " ", line)
                 line = line.replace("defined", " ")
                 for m in line.split()[1:]:
                     if re.match("[0-9]+[ulUL]*", m):
@@ -131,9 +137,9 @@ def validate(cp2k_dir, filelist=None, excluded_dirs=DEFAULT_EXCLUDED_DIRS):
 
     flags = [f for f in flags if not flag_exceptions_re.match(f)]
 
-    with open(path.join(cp2k_dir, "INSTALL.md")) as fhandle:
+    with open(path.join(cp2k_dir, "INSTALL.md"), encoding="utf8") as fhandle:
         install_txt = fhandle.read()
-    with open(path.join(cp2k_dir, "src/cp2k_info.F")) as fhandle:
+    with open(path.join(cp2k_dir, "src/cp2k_info.F"), encoding="utf8") as fhandle:
         cp2k_info = fhandle.read()
 
     flags_src = re.search(
@@ -151,7 +157,7 @@ def validate(cp2k_dir, filelist=None, excluded_dirs=DEFAULT_EXCLUDED_DIRS):
         data_files = set()
         for _, _, files in os.walk(path.join(cp2k_dir, "data")):
             data_files.update(files)
-        data_files.remove("README")
+        data_files.remove("README.md")
         for root, _, files in os.walk(path.join(cp2k_dir, "tests")):
             d = path.relpath(root, cp2k_dir)
             for c in data_files.intersection(files):
@@ -170,6 +176,9 @@ def validate(cp2k_dir, filelist=None, excluded_dirs=DEFAULT_EXCLUDED_DIRS):
             absfn = path.join(root, fn)
             shortfn = path.relpath(absfn, cp2k_dir)
 
+            if not portable_filename_re.match(fn):
+                warnings += ["Filename %s not portable" % shortfn]
+
             if not path.exists(absfn):
                 continue  # skip broken symlinks
 
@@ -181,21 +190,6 @@ def validate(cp2k_dir, filelist=None, excluded_dirs=DEFAULT_EXCLUDED_DIRS):
             if b"\r\n" in content:
                 warnings += ["Text file %s contains DOS linebreaks" % shortfn]
 
-            # check for non-ascii chars
-            if b"# -*- coding: utf-8 -*-" in content:
-                continue
-
-            if not re.search(b"[\x80-\xFF]", content):
-                continue
-
-            for lineno, line in enumerate(content.splitlines()):
-                m = re.search(b"[\x80-\xFF]", line)
-                if m:
-                    warnings += [
-                        "Found non-ascii char in %s line %d at position %d"
-                        % (shortfn, lineno + 1, m.start(0) + 1)
-                    ]
-
     return warnings
 
 
