@@ -1,5 +1,8 @@
 #!/bin/bash
 
+set -o nounset
+set -o pipefail
+
 # Test if coding conventions are fulfilled
 # author: Ole Schuett
 
@@ -8,7 +11,7 @@ date --utc --rfc-3339=seconds
 
 (
   set -e # abort if error is encountered
-  cd ../../makefiles
+  cd ../../
   make -j ARCH=Linux-x86-64-gfortran VERSION="dumpast" > make_conventions1.out
   make -j ARCH=local_warn            VERSION="psmp"    > make_conventions2.out
 )
@@ -23,9 +26,11 @@ if (( $MAKE_EXIT_CODE )); then
    echo "Status: FAILED"
 else
    rm -f *.issues
+
+   set -o errexit
+
    ./analyze_gfortran_ast.py      ../../obj/Linux-x86-64-gfortran/dumpast/*.ast > ast.issues
    ./analyze_gfortran_warnings.py ../../obj/local_warn/psmp/*.warn              > warn.issues
-   ./analyze_src.py               ../../                                        > src.issues
+   ./analyze_src.py               -b ../../                                     > src.issues
    ./summarize_issues.py --suppressions=conventions.supp *.issues
 fi
-#EOF
