@@ -9,8 +9,9 @@ apt-get install -qq --no-install-recommends \
     build-essential                         \
     make                                    \
     perl                                    \
-    python                                  \
-    python3-{pip,setuptools,wheel,dev}
+    python3-{pip,setuptools,wheel,dev}      \
+    nodejs                                  \
+    clang-format
 
 rm -rf /var/lib/apt/lists/*
 
