@@ -8,38 +8,44 @@ source /opt/cp2k-toolchain/install/setup
 echo -e "\n========== Compiling CP2K =========="
 cd /workspace/cp2k
 echo -n "Compiling cp2k... "
-if make -j VERSION=pdbg &> /dev/null ; then
-   echo "done."
+if make -j VERSION=pdbg &> make.out ; then
+    echo "done."
 else
-   echo -e "failed.\n\n"
-   echo "Summary: Compilation failed."
-   echo "Status: FAILED"
-   exit
+    echo -e "failed.\n\n"
+    tail -n 100 make.out
+    echo -e "\nSummary: Compilation failed."
+    echo -e "Status: FAILED\n"
+    exit 0
 fi
 
 echo -e "\n========== Installing i-Pi =========="
 cd /opt/i-pi
 git pull --quiet
-pip install --quiet .
+pip3 install --quiet .
 
 echo -e "\n========== Running i-Pi Tests =========="
 
 cd  /opt/i-pi/examples/cp2k/nvt-cl
 set +e # disable error trapping for remainder of script
 
+TIMEOUT_SEC="300"
+ulimit -t ${TIMEOUT_SEC}  # Limit cpu time.
+
 # launch cp2k
 (
   mkdir -p run_1
   cd run_1
   echo 42 > cp2k_exit_code
-  sleep 2 # give i-pi some time to startup
+  sleep 10 # give i-pi some time to startup
+  export OMP_NUM_THREADS=2
   mpiexec -np 2 /workspace/cp2k/exe/local/cp2k.pdbg ../in.cp2k
   echo $? > cp2k_exit_code
 ) &
 
 # launch i-pi
 sed -i "s/total_steps>1000/total_steps>10/" input.xml
-/usr/local/bin/i-pi input.xml
+# Limit walltime too, because waiting for a connection consumes no cpu time.
+timeout ${TIMEOUT_SEC} /usr/local/bin/i-pi input.xml
 IPI_EXIT_CODE=$?
 
 wait # for cp2k to shutdown
