@@ -6,13 +6,11 @@
 set -e
 rm -rf preprettify
 
-find ./src/ -type f -not -path "*/preprettify/*" -not -path "*/.svn/*" -print0 | xargs -0 md5sum > checksums.md5
+find ./src/ -type f -not -path "*/preprettify/*" -not -path "*/.git/*" -print0 | xargs -0 md5sum > checksums.md5
 md5sum ./data/POTENTIAL >> checksums.md5
 
-cd makefiles
-make --jobs=20 pretty
-make --jobs=20 pretty  # run twice to ensure consistency with doxify
-cd ..
+make -j 16 pretty
+make -j 16 pretty  # run twice to ensure consistency with doxify
 
 cd data
 cat GTH_POTENTIALS HF_POTENTIALS NLCC_POTENTIALS ALL_POTENTIALS > POTENTIAL
@@ -26,7 +24,7 @@ echo "Searching for doxify warnings ..."
 if grep -r -e "UNMATCHED_PROCEDURE_ARGUMENT" \
            -e "UNKNOWN_DOXYGEN_COMMENT" \
            -e "UNKNOWN_COMMENT" \
-           --exclude-dir=".svn" \
+           --exclude-dir=".git" \
            --exclude-dir="preprettify" \
            ./src/* ; then
   summary="Found doxify warnings"
