@@ -1,26 +1,16 @@
-#!/usr/bin/env python
-
-from __future__ import print_function
+#!/usr/bin/env python3
 
 import sys
 import re
 import tempfile
 import os
-from os import path
 import logging
 import argparse
 import errno
-import traceback
-
-try:
-    from hashlib import md5
-except ImportError:
-    from md5 import new as md5
-
-try:
-    from cStringIO import StringIO
-except ImportError:
-    from io import StringIO
+import contextlib
+from os import path
+from hashlib import md5
+from io import StringIO
 
 from prettify_cp2k import normalizeFortranFile
 from prettify_cp2k import replacer
@@ -116,6 +106,14 @@ LINE_PARTS_RE = re.compile(
 )
 
 
+@contextlib.contextmanager
+def rewind(fhandle):
+    try:
+        yield fhandle
+    finally:
+        fhandle.seek(0)
+
+
 def upcaseStringKeywords(line):
     """Upcases the fortran keywords, operators and intrinsic routines
     in line"""
@@ -173,12 +171,12 @@ def prettifyFile(
     does not close the input file"""
     max_pretty_iter = 5
 
-    logger = logging.getLogger("fprettify-logger")
+    logger = logging.getLogger("prettify-logger")
 
     if is_fypp(infile):
         logger.warning(
             "fypp directives not fully supported, running only fprettify",
-            extra={"ffilename": filename, "fline": 0},
+            extra={"ffilename": filename},
         )
         replace = False
         normalize_use = False
@@ -190,80 +188,73 @@ def prettifyFile(
     hash_prev = md5(inbuf.getvalue().encode("utf8"))
 
     for _ in range(max_pretty_iter):
-        try:
-            if replace:
-                outbuf = StringIO()
-                replacer.replaceWords(inbuf, outbuf)
+        if replace:
+            outbuf = StringIO()
+            replacer.replaceWords(inbuf, outbuf)
+            outbuf.seek(0)
+            inbuf.close()
+            inbuf = outbuf
+
+        if reformat:  # reformat needs to be done first
+            outbuf = StringIO()
+            try:
+                reformat_ffile(
+                    inbuf,
+                    outbuf,
+                    indent_size=indent,
+                    whitespace=whitespace,
+                    orig_filename=filename,
+                )
+            except fparse_utils.FprettifyParseException as e:
+                log_exception(
+                    e, "fprettify could not parse file, file is not prettified"
+                )
+                outbuf.close()
+                inbuf.seek(0)
+            else:
                 outbuf.seek(0)
                 inbuf.close()
                 inbuf = outbuf
 
-            if reformat:  # reformat needs to be done first
-                outbuf = StringIO()
-                try:
-                    reformat_ffile(
-                        inbuf,
-                        outbuf,
-                        indent_size=indent,
-                        whitespace=whitespace,
-                        orig_filename=filename,
-                    )
-                except fparse_utils.FprettifyParseException as e:
-                    log_exception(
-                        e, "fprettify could not parse file, file is not prettified"
-                    )
-                    outbuf.close()
-                    inbuf.seek(0)
-                else:
-                    outbuf.seek(0)
-                    inbuf.close()
-                    inbuf = outbuf
+        normalize_use_succeeded = True
 
-            normalize_use_succeeded = True
-
-            if normalize_use:
-                outbuf = StringIO()
-                try:
-                    normalizeFortranFile.rewriteFortranFile(
-                        inbuf,
-                        outbuf,
-                        indent,
-                        decl_linelength,
-                        decl_offset,
-                        orig_filename=filename,
-                    )
-                except normalizeFortranFile.InputStreamError as exc:
-                    logger.error(
-                        "normalizeFortranFile could not parse file, file is not normalized",
-                        extra={"ffilename": filename, "fline": 0},
-                    )
-                    outbuf.close()
-                    inbuf.seek(0)
-                    normalize_use_succeeded = False
-                else:
-                    outbuf.seek(0)
-                    inbuf.close()
-                    inbuf = outbuf
-
-            if upcase_keywords and normalize_use_succeeded:
-                outbuf = StringIO()
-                upcaseKeywords(inbuf, outbuf, upcase_omp)
+        if normalize_use:
+            outbuf = StringIO()
+            try:
+                normalizeFortranFile.rewriteFortranFile(
+                    inbuf,
+                    outbuf,
+                    indent,
+                    decl_linelength,
+                    decl_offset,
+                    orig_filename=filename,
+                )
+            except normalizeFortranFile.InputStreamError as exc:
+                logger.exception(
+                    "normalizeFortranFile could not parse file, file is not normalized",
+                    extra={"ffilename": filename},
+                )
+                outbuf.close()
+                inbuf.seek(0)
+                normalize_use_succeeded = False
+            else:
                 outbuf.seek(0)
                 inbuf.close()
                 inbuf = outbuf
 
-            hash_new = md5(inbuf.getvalue().encode("utf8"))
+        if upcase_keywords and normalize_use_succeeded:
+            outbuf = StringIO()
+            upcaseKeywords(inbuf, outbuf, upcase_omp)
+            outbuf.seek(0)
+            inbuf.close()
+            inbuf = outbuf
 
-            if hash_prev.digest() == hash_new.digest():
-                return inbuf
+        hash_new = md5(inbuf.getvalue().encode("utf8"))
 
-            hash_prev = hash_new
+        if hash_prev.digest() == hash_new.digest():
+            return inbuf
 
-        except:
-            logger.critical(
-                "error processing file", extra={"ffilename": filename, "fline": 0}
-            )
-            raise
+        hash_prev = hash_new
 
     else:
         raise RuntimeError(
@@ -272,14 +263,16 @@ def prettifyFile(
 
 
 def prettifyInplace(filename, backupdir=None, stdout=False, **kwargs):
-    """Same as prettify, but inplace, replaces only if needed"""
+    """Same as prettify, but inplace, replaces only if needed
+    :return: True if file was modified, False if otherwise. If stdin/stdout, always False.
+    """
 
     if filename == "stdin":
         infile = tempfile.TemporaryFile(mode="r+")
         infile.write(sys.stdin.read())
         infile.seek(0)
     else:
-        infile = open(filename, "r")
+        infile = open(filename, "r", encoding="utf8")
 
     outfile = prettifyFile(infile=infile, filename=filename, **kwargs)
 
@@ -287,11 +280,11 @@ def prettifyInplace(filename, backupdir=None, stdout=False, **kwargs):
         outfile.seek(0)
         sys.stdout.write(outfile.read())
         outfile.close()
-        return
+        return False
 
     if infile == outfile:
         infile.close()
-        return
+        return False
 
     infile.seek(0)
     outfile.seek(0)
@@ -306,13 +299,13 @@ def prettifyInplace(filename, backupdir=None, stdout=False, **kwargs):
         if backupdir:
             bkName = path.join(backupdir, path.basename(filename))
 
-            with open(bkName, "w") as fhandle:
+            with open(bkName, "w", encoding="utf8") as fhandle:
                 infile.seek(0)
                 fhandle.write(infile.read())
 
         infile.close()  # close it here since we're going to overwrite it
 
-        with open(filename, "w") as fhandle:
+        with open(filename, "w", encoding="utf8") as fhandle:
             outfile.seek(0)
             fhandle.write(outfile.read())
 
@@ -321,6 +314,8 @@ def prettifyInplace(filename, backupdir=None, stdout=False, **kwargs):
 
     outfile.close()
 
+    return changed
+
 
 def is_fypp(infile):
     FYPP_SYMBOLS = r"(#|\$|@)"
@@ -329,12 +324,13 @@ def is_fypp(infile):
     FYPP_RE = re.compile(r"(" + FYPP_LINE + r"|" + FYPP_INLINE + r")")
 
     infile.seek(0)
-    for line in infile.readlines():
-        if FYPP_RE.search(line):
-            return True
 
-    infile.seek(0)
-    return False
+    with rewind(infile) as fhandle:
+        for line in fhandle.readlines():
+            if FYPP_RE.search(line):
+                return True
+
+        return False
 
 
 # based on https://stackoverflow.com/a/31347222
@@ -359,11 +355,6 @@ def mkdir_p(p):
             raise
 
 
-# from https://stackoverflow.com/a/14981125
-def eprint(*args, **kwargs):
-    print(*args, file=sys.stderr, **kwargs)
-
-
 def abspath(p):
     return path.abspath(path.expanduser(p))
 
@@ -421,6 +412,9 @@ def main(argv):
         False,
         "store backups of original files in backup-dir (--backup-dir option)",
     )
+    argparse_add_bool_arg(
+        parser, "quiet", False, "don't show summary or list of reformatted files"
+    )
     argparse_add_bool_arg(parser, "report-errors", True, "report warnings and errors")
     argparse_add_bool_arg(parser, "debug", False, "increase log level to debug")
 
@@ -431,34 +425,45 @@ def main(argv):
     if args.do_backup and not (args.stdout or args.files == ["stdin"]):
         mkdir_p(args.backup_dir)
 
+    level = logging.CRITICAL
+
+    if args.report_errors:
+        if args.debug:
+            level = logging.DEBUG
+        else:
+            level = logging.ERROR
+
+    # the fprettify logger provides filename and line number in case of errors
+    shandler = logging.StreamHandler()
+    shandler.setLevel(level)
+    shandler.setFormatter(
+        logging.Formatter("%(levelname)s %(ffilename)s:%(fline)s: %(message)s")
+    )
+
+    fprettify_logger = logging.getLogger("fprettify-logger")
+    fprettify_logger.setLevel(level)
+    fprettify_logger.addHandler(shandler)
+
+    # the prettify_cp2k loggers only provide the filename in their messages
+    shandler = logging.StreamHandler()
+    shandler.setLevel(level)
+    shandler.setFormatter(logging.Formatter("%(levelname)s %(ffilename)s: %(message)s"))
+
+    logger = logging.getLogger("prettify-logger")
+    logger.setLevel(level)
+    logger.addHandler(shandler)
+
     failure = 0
+    total_prettified = 0
 
     for filename in args.files:
         if not path.isfile(filename) and not filename == "stdin":
-            eprint("file '{}' does not exist!".format(filename))
+            logger.error(f"file '{filename}' does not exist")
             failure += 1
             continue
 
-        level = logging.CRITICAL
-
-        if args.report_errors:
-            if args.debug:
-                level = logging.DEBUG
-            else:
-                level = logging.INFO
-
-        logger = logging.getLogger("fprettify-logger")
-        logger.setLevel(level)
-        sh = logging.StreamHandler()
-        sh.setLevel(level)
-        formatter = logging.Formatter(
-            "%(levelname)s %(ffilename)s:%(fline)s: %(message)s"
-        )
-        sh.setFormatter(formatter)
-        logger.addHandler(sh)
-
         try:
-            prettifyInplace(
+            changed = prettifyInplace(
                 filename,
                 backupdir=args.backup_dir if args.do_backup else None,
                 stdout=args.stdout or filename == "stdin",
@@ -472,13 +477,20 @@ def main(argv):
                 upcase_omp=args.omp_upcase,
                 replace=args.replace,
             )
+
+            if changed and not args.quiet:
+                print(f"prettified {filename}")
+                total_prettified += 1
+
         except:
-            eprint("-" * 60)
-            traceback.print_exc(file=sys.stderr)
-            eprint("-" * 60)
-            eprint("Processing file '{}'".format(filename))
+            logger.exception("processing file failed", extra={"ffilename": filename})
             failure += 1
 
+    if not (args.stdout or filename == "stdin" or args.quiet):
+        print(
+            f"{total_prettified} file(s) prettified, {len(args.files) - total_prettified} file(s) left unchanged."
+        )
+
     return failure > 0
 
 
