@@ -4,7 +4,7 @@ SCRIPT_DIR="$(cd "$(dirname "$SCRIPT_NAME")" && pwd -P)"
 
 # +-----------------------------------------------------------------------+
 # |  CP2K: A general program to perform molecular dynamics simulations    |
-# |  Copyright (C) 2000 - 2019  CP2K developers group                     |
+# |  Copyright (C) 2000 - 2020  CP2K developers group                     |
 # +-----------------------------------------------------------------------+
 #
 # *****************************************************************************
@@ -74,14 +74,14 @@ OPTIONS:
                           --with-PKG option placed AFTER this option on the
                           command line.
 --mpi-mode                Selects which MPI flavour to use. Available options
-                          are: mpich, openmpi and no. By selecting no, you will
-                          be disabling MPI support. By default the script
+                          are: mpich, openmpi, intelmpi, and no. By selecting no,
+                          you will be disabling MPI support. By default the script
                           will try to determine the flavour based on the MPI library
                           currently available in your system path. For CRAY (CLE)
                           systems, the default flavour is mpich. Note that explicitly
-                          setting --with-mpich or --with-openmpi options to values
-                          other than no will also switch --mpi-mode to the respective
-                          mode.
+                          setting --with-mpich, --with-openmpi or --with-intelmpi
+                          options to values other than no will also switch --mpi-mode
+                          to the respective mode.
 --math-mode               Selects which core math library to use. Available options
                           are: acml, cray, mkl, openblas and reflapack. cray
                           corresponds to cray libsci, and is the default for CRAY
@@ -100,7 +100,7 @@ OPTIONS:
 --libint-lmax             Maximum supported angular momentum by libint.
                           Higher values will increase build time and library size.
                           Default = 5
---dry-run                 Write only config files, but dont' actually build packages.
+--dry-run                 Write only config files, but don't actually build packages.
 
 The --enable-FEATURE options follow the rules:
   --enable-FEATURE=yes    Enable this particular feature
@@ -120,8 +120,6 @@ The --enable-FEATURE options follow the rules:
                           this option forces the master development version
                           to be installed.
                           Default = no
-  --enable-omp            Turn on OpenMP (threading) support.
-                          Default = yes
   --enable-cuda           Turn on GPU (CUDA) support.
                           Default = no
   --enable-cray           Turn on or off support for CRAY Linux Environment
@@ -144,7 +142,7 @@ The --with-PKG options follow the rules:
 
   --with-gcc              The GCC compiler to use to compile CP2K
                           Default = system
-  --with-cmake            Cmake utilities, required for building ParMETIS
+  --with-cmake            Cmake utilities
                           Default = no
   --with-valgrind         Valgrind memory debugging tool, only used for
                           debugging purposes.
@@ -153,7 +151,10 @@ The --with-PKG options follow the rules:
                           of CP2K.
                           Default = system
   --with-mpich            MPICH, MPI library like OpenMPI. one should
-                          only use EITHER OpenMPI or MPICH and not both.
+                          use only one of OpenMPI, MPICH or Intel MPI.
+                          Default = system
+  --with-intelmpi         Intel MPI, MPI library like OpenMPI. one should
+                          use only one of OpenMPI, MPICH or Intel MPI.
                           Default = system
   --with-libxc            libxc, exchange-correlation library. Needed for
                           QuickStep DFT and hybrid calculations.
@@ -197,14 +198,6 @@ The --with-PKG options follow the rules:
                           Default = install
   --with-ptscotch         PT-SCOTCH, only used if PEXSI is used
                           Default = no
-  --with-parmetis         ParMETIS, and if --with-parmetis=install will also install
-                          METIS, only used if PEXSI is used
-                          Default = no
-  --with-metis            METIS, --with-metis=install actually does nothing, because
-                          METIS is installed together with ParMETIS.  This option
-                          is used to specify the METIS library if it is pre-installed
-                          else-where. Only used if PEXSI is used
-                          Default = no
   --with-superlu          SuperLU DIST, used only if PEXSI is used
                           Default = no
   --with-pexsi            Enable interface to PEXSI library
@@ -227,6 +220,10 @@ The --with-PKG options follow the rules:
                           Default = install
   --with-spfft            Enable the spare fft used in SIRIUS (hard dependency)
                           Default = install
+  --with-cosma            Enable cosma as a replacement for scalapack matrix multiplication
+                          Default = install
+  --with-libvori          Enable libvori for the Voronoi integration (and the BQB compressed trajectory format)
+                          Default = install
 
 FURTHER INSTRUCTIONS
 
@@ -260,10 +257,11 @@ EOF
 # is important, the first in the list gets installed first
 # ------------------------------------------------------------------------
 tool_list="gcc cmake valgrind"
-mpi_list="mpich openmpi"
+mpi_list="mpich openmpi intelmpi"
 math_list="mkl acml openblas reflapack"
-lib_list="fftw libint libxc libsmm libxsmm scalapack elpa plumed \
-          spfft ptscotch parmetis metis superlu pexsi quip gsl spglib hdf5 libvdwxc sirius"
+lib_list="fftw libint libxc libsmm libxsmm cosma scalapack elpa plumed \
+          spfft ptscotch superlu pexsi quip gsl spglib hdf5 libvdwxc sirius
+          libvori"
 package_list="$tool_list $mpi_list $math_list $lib_list"
 # ------------------------------------------------------------------------
 
@@ -288,7 +286,7 @@ with_scalapack=__INSTALL__
 # default math library settings, FAST_MATH_MODE picks the math library
 # to use, and with_* defines the default method of installation if it
 # is picked. For non-CRAY systems defaults to mkl if $MKLROOT is
-# avaliable, otherwise defaults to openblas
+# available, otherwise defaults to openblas
 if [ "$MKLROOT" ] ; then
     export FAST_MATH_MODE=mkl
 else
@@ -301,24 +299,30 @@ with_reflapack=__DONTUSE__
 
 # sirius is activated by default
 with_sirius="__INSTALL__"
-with_gsl="__INSTALL__"
+with_gsl="__DONTUSE__"
 with_spglib="__INSTALL__"
-with_hdf5="__INSTALL__"
+with_hdf5="__DONTUSE__"
 with_elpa="__INSTALL__"
-with_libvdwxc="__INSTALL__"
-with_spfft=__INSTALL__
-
+with_libvdwxc="__DONTUSE__"
+with_spfft="__DONTUSE__"
+with_cosma="__INSTALL__"
+with_libvori="__INSTALL__"
 # for MPI, we try to detect system MPI variant
 with_openmpi=__SYSTEM__
 with_mpich=__SYSTEM__
+with_intelmpi=__SYSTEM__
 if (command -v mpirun >&- 2>&-) ; then
-    # check if we are dealing with openmpi or mpich
+    # check if we are dealing with openmpi, mpich or intelmpi
     if (mpirun --version 2>&1 | grep -s -q "HYDRA") ; then
         echo "MPI is detected and it appears to be MPICH"
         export MPI_MODE=mpich
     elif (mpirun --version 2>&1 | grep -s -q "Open MPI") ; then
         echo "MPI is detected and it appears to be OpenMPI"
         export MPI_MODE=openmpi
+    elif (mpirun --version 2>&1 | grep -s -q "Intel") ; then
+        echo "MPI is detected and it appears to be Intel MPI"
+        with_gcc=__DONTUSE__
+        export MPI_MODE=intelmpi
     else
         # default to mpich
         export MPI_MODE=mpich
@@ -336,7 +340,6 @@ dry_run=__FALSE__
 enable_tsan=__FALSE__
 enable_gcc_master=__FALSE__
 enable_libxsmm_master=__FALSE__
-enable_omp=__TRUE__
 if (command -v nvcc >&- 2>&-) ; then
    echo "nvcc found, enabling CUDA by default"
    enable_cuda=__TRUE__
@@ -358,6 +361,7 @@ if [ "$CRAY_LD_LIBRARY_PATH" ] ; then
     # don't use the installers for the MPI libraries
     with_mpich="__DONTUSE__"
     with_openmpi="__DONTUSE__"
+    with_intelmpi="__DONTUSE__"
     export MPI_MODE=mpich
     # set default value for some installers appropriate for CLE
     with_gcc="__DONTUSE__"
@@ -397,12 +401,15 @@ while [ $# -ge 1 ] ; do
                 openmpi)
                     export MPI_MODE=openmpi
                     ;;
+                intelmpi)
+                    export MPI_MODE=intelmpi
+                    ;;
                 no)
                     export MPI_MODE=no
                     ;;
                 *)
                     report_error ${LINENO} \
-                                 "--mpi-mode currently only supports openmpi, mpich and no as options"
+                                 "--mpi-mode currently only supports openmpi, mpich, intelmpi and no as options"
                     exit 1
                     ;;
             esac
@@ -486,13 +493,6 @@ while [ $# -ge 1 ] ; do
                 exit 1
             fi
             ;;
-        --enable-omp*)
-            enable_omp=$(read_enable $1)
-            if [ $enable_omp = "__INVALID__" ] ; then
-                report_error "invalid value for --enable-omp, please use yes or no"
-                exit 1
-            fi
-            ;;
         --enable-cuda*)
             enable_cuda=$(read_enable $1)
             if [ $enable_cuda = "__INVALID__" ] ; then
@@ -528,6 +528,12 @@ while [ $# -ge 1 ] ; do
                 export MPI_MODE=openmpi
             fi
             ;;
+        --with-intelmpi*)
+            with_intelmpi=$(read_with $1)
+            if [ $with_intelmpi != __DONTUSE__ ] ; then
+                export MPI_MODE=intelmpi
+            fi
+            ;;
         --with-libint*)
             with_libint=$(read_with $1)
             ;;
@@ -573,12 +579,6 @@ while [ $# -ge 1 ] ; do
         --with-ptscotch*)
             with_ptscotch=$(read_with $1)
             ;;
-        --with-parmetis*)
-            with_parmetis=$(read_with $1)
-            ;;
-        --with-metis*)
-            with_metis=$(read_with $1)
-            ;;
         --with-superlu*)
             with_superlu=$(read_with $1)
             ;;
@@ -609,6 +609,12 @@ while [ $# -ge 1 ] ; do
         --with-spfft*)
             with_spfft=$(read_with $1)
             ;;
+        --with-cosma*)
+            with_cosma=$(read_with $1)
+            ;;
+        --with-libvori*)
+            with_libvori=$(read_with $1)
+            ;;
         --help*)
             show_help
             exit 0
@@ -627,7 +633,6 @@ done
 
 # consolidate settings after user input
 export ENABLE_TSAN=$enable_tsan
-export ENABLE_OMP=$enable_omp
 export ENABLE_CUDA=$enable_cuda
 export ENABLE_CRAY=$enable_cray
 [ "$enable_gcc_master" = "__TRUE__" ] && export gcc_ver=master
@@ -679,12 +684,17 @@ if [ $MPI_MODE = no ] ; then
         echo "Not using MPI, so spfft is disabled"
         with_spfft="__DONTUSE__"
     fi
+    if [ "$with_cosma" != "__DONTUSE__" ] ; then
+        echo "Not using MPI, so cosma is disabled"
+        with_cosma="__DONTUSE__"
+    fi
 else
     # if gcc is installed, then mpi needs to be installed too
     if [ "$with_gcc" = "__INSTALL__" ] ; then
         echo "You have chosen to install GCC, therefore MPI libraries will have to be installed too"
         with_openmpi="__INSTALL__"
         with_mpich="__INSTALL__"
+        with_intelmpi="__DONTUSE__"
     fi
 fi
 
@@ -702,78 +712,39 @@ if [ "$with_pexsi" = "__DONTUSE__" ] ; then
         echo "Not using PEXSI, so PT-Scotch is disabled."
         with_ptscotch="__DONTUSE__"
     fi
-    if [ "$with_parmetis" != "__DONTUSE__" ] ; then
-        echo "Not using PEXSI, so ParMETIS is disabled."
-        with_parmetis="__DONTUSE__"
-    fi
-    if [ "$with_metis" != "__DONTUSE__" ] ; then
-        echo "Not using PEXSI, so METIS is disabled."
-        with_metis="__DONTUSE__"
-    fi
     if [ "$with_superlu" != "__DONTUSE__" ] ; then
         echo "Not using PEXSI, so SuperLU-DIST is disabled."
         with_superlu="__DONTUSE__"
     fi
 elif [ "$with_pexsi" = "__INSTALL__" ] ; then
     [ "$with_ptscotch" = "__DONTUSE__" ] && with_ptscotch="__INSTALL__"
-    [ "$with_parmetis" = "__DONTUSE__" ] && with_parmetis="__INSTALL__"
     [ "$with_superlu" = "__DONTUSE__" ] && with_superlu="__INSTALL__"
 else
     if [ "$with_ptscotch" = "__DONTUSE__" ] ; then
         report_error "For PEXSI to work you need a working PT-Scotch library use --with-ptscotch option to specify if you wish to install the library or specify its location."
         exit 1
     fi
-    if [ "$with_parmetis" = "__DONTUSE__" ] ; then
-        report_error "For PEXSI to work you need a working PARMETIS library use --with-parmetis option to specify if you wish to install the library or specify its location."
-        exit 1
-    fi
-    if [ "$with_metis" = "__DONTUSE__" ] ; then
-        report_error "For PEXSI to work you need a working METIS library use --with-metis option to specify if you wish to install the library or specify its location."
-        exit 1
-    fi
     if [ "$with_superlu" = "__DONTUSE__" ] ; then
         report_error "For PEXSI to work you need a working SuperLU-DIST library use --with-superlu option to specify if you wish to install the library or specify its location."
         exit 1
     fi
 fi
 
-# ParMETIS requires cmake, it also installs METIS if it is chosen
-if [ "$with_parmetis" = "__INSTALL__" ] ; then
-    [ "$with_cmake" = "__DONTUSE__" ] && with_cmake="__INSTALL__"
-    with_metis="__INSTALL__"
-fi
-
-# spg library requires cmake.
-if [ "$with_spglib" = "__INSTALL__" ] ; then
+# spglib and libvori require cmake.
+if [ "$with_spglib" = "__INSTALL__" ] || [ "$with_libvori" = "__INSTALL__" ] ; then
     [ "$with_cmake" = "__DONTUSE__" ] && with_cmake="__INSTALL__"
 fi
 
 # SIRIUS dependencies. Remove the gsl library from the dependencies if SIRIUS is not activated
 if [ "$with_sirius" = "__INSTALL__" ] ; then
-    if [ "$with_spfft" = "__DONTUSE__" ] ; then
-        report_error "For SIRIUS to work you need a working spfft library use --with-spfft option to specify if you wish to install the library or specify its location."
-        exit 1
-    fi
-    if [ "$with_gsl" = "__DONTUSE__" ] ; then
-        report_error "For SIRIUS to work you need a working gsl library use --with-gsl option to specify if you wish to install the library or specify its location."
-        exit 1
-    fi
-    if [ "$with_libxc" = "__DONTUSE__" ] ; then
-        report_error "For SIRIUS to work you need a working libxc library use --with-libxc option to specify if you wish to install the library or specify its location."
-        exit 1
-    fi
-    if [ "$with_fftw" = "__DONTUSE__" ] ; then
-        report_error "For SIRIUS to work you need a working fftw library use --with-fftw option to specify if you wish to install the library or specify its location."
-        exit 1
-    fi
-    if [ "$with_spglib" = "__DONTUSE__" ] ; then
-        report_error "For SIRIUS to work you need a working spglib library use --with-spglib option to specify if you wish to install the library or specify its location."
-        exit 1
-    fi
-    if [ "$with_hdf5" = "__DONTUSE__" ] ; then
-        report_error "For SIRIUS to work you need a working hdf5 library use --with-hdf5 option to specify if you wish to install the library or specify its location."
-        exit 1
-    fi
+    [ "$with_spfft" = "__DONTUSE__" ] && with_spfft="__INSTALL__"
+    [ "$with_gsl" = "__DONTUSE__" ] && with_gsl="__INSTALL__"
+    [ "$with_libxc" = "__DONTUSE__" ] && with_libxc="__INSTALL__"
+    [ "$with_fftw" = "__DONTUSE__" ] && with_fftw="__INSTALL__"
+    [ "$with_spglib" = "__DONTUSE__" ] && with_spglib="__INSTALL__"
+    [ "$with_hdf5" = "__DONTUSE__" ] && with_hdf5="__INSTALL__"
+    [ "$with_libvdwxc" = "__DONTUSE__" ] && with_libvdwxc="__INSTALL__"
+    [ "$with_cosma" = "__DONTUSE__" ] && with_cosma="__INSTALL__"
 fi
 
 # ------------------------------------------------------------------------
@@ -785,7 +756,7 @@ mkdir -p "$INSTALLDIR"
 # variables used for generating cp2k ARCH file
 export CP_DFLAGS=''
 export CP_LIBS=''
-export CP_CFLAGS='IF_OMP(-fopenmp|)'
+export CP_CFLAGS='-fopenmp'
 export CP_LDFLAGS="-Wl,--enable-new-dtags"
 
 # ------------------------------------------------------------------------
@@ -854,6 +825,17 @@ if [ "$ENABLE_CRAY" = "__TRUE__" ] ; then
                 export CP_DFLAGS="${CP_DFLAGS} IF_MPI(-D__parallel -D__MPI_VERSION=3|)"
             fi
             ;;
+        intelmpi)
+            if [ "$with_intelmpi" = "__DONTUSE__" ] ; then
+                with_gcc=__DONTUSE__
+                add_include_from_paths MPI_CFLAGS "mpi.h" $INCLUDE_PATHS
+                add_include_from_paths MPI_LDFLAGS "libmpi.*" $LIB_PATHS
+                export MPI_CFLAGS
+                export MPI_LDFLAGS
+                export MPI_LIBS="-lmpi -lmpi_cxx"
+                export CP_DFLAGS="${CP_DFLAGS} IF_MPI(-D__parallel -D__MPI_VERSION=3|)"
+            fi
+            ;;
     esac
     check_lib -lz
     check_lib -ldl
@@ -904,8 +886,7 @@ case $GPUVER in
         "--gpu-ver currently only supports K20X, K40, K80, P100, V100 as options"
 esac
 
-# write toolchain environment
-export -p > "${INSTALLDIR}"/toolchain.env
+write_toolchain_env "${INSTALLDIR}"
 
 # write toolchain config
 echo "tool_list=\"${tool_list}\"" > "${INSTALLDIR}"/toolchain.conf
@@ -924,29 +905,30 @@ else
     ./scripts/install_gcc.sh
     ./scripts/setup_buildtools.sh
     ./scripts/install_cmake.sh
-    ./scripts/install_valgrind.sh
     ./scripts/install_mpich.sh
     ./scripts/install_openmpi.sh
+    ./scripts/install_intelmpi.sh
+    ./scripts/install_valgrind.sh
     ./scripts/install_mathlibs.sh
     ./scripts/install_fftw.sh
-    ./scripts/install_spfft.sh
     ./scripts/install_libint.sh
     ./scripts/install_libxc.sh
     ./scripts/install_libsmm.sh
     ./scripts/install_libxsmm.sh
     ./scripts/install_scalapack.sh
+    ./scripts/install_cosma.sh
     ./scripts/install_elpa.sh
     ./scripts/install_ptscotch.sh
-    ./scripts/install_parmetis.sh
-    ./scripts/install_metis.sh
     ./scripts/install_superlu.sh
     ./scripts/install_pexsi.sh
     ./scripts/install_quip.sh
     ./scripts/install_plumed.sh
     ./scripts/install_gsl.sh
-    ./scripts/install_spglib.sh
     ./scripts/install_hdf5.sh
     ./scripts/install_libvdwxc.sh
+    ./scripts/install_spglib.sh
+    ./scripts/install_libvori.sh
+    ./scripts/install_spfft.sh
     ./scripts/install_sirius.sh
     ./scripts/generate_arch_files.sh
 fi
