@@ -2,8 +2,13 @@
 [ "${BASH_SOURCE[0]}" ] && SCRIPT_NAME="${BASH_SOURCE[0]}" || SCRIPT_NAME=$0
 SCRIPT_DIR="$(cd "$(dirname "$SCRIPT_NAME")" && pwd -P)"
 
-gcc_ver="8.3.0"
-gcc_sha256="ea71adc1c3d86330874b8df19611424b143308f0d6612d542472600532c96d2d"
+gcc_ver="10.2.0"
+gcc_sha256="27e879dccc639cd7b0cc08ed575c1669492579529b53c9ff27b0b96265fa867d"
+
+patches=(
+    "${SCRIPT_DIR}/files/gcc-${gcc_ver}-cpp-__has_include.patch"
+    )
+
 source "${SCRIPT_DIR}"/common_vars.sh
 source "${SCRIPT_DIR}"/tool_kit.sh
 source "${SCRIPT_DIR}"/signal_trap.sh
@@ -41,6 +46,11 @@ case "$with_gcc" in
             fi
             echo "Installing GCC from scratch into ${pkg_install_dir}"
             cd gcc-${gcc_ver}
+
+            for patch in "${patches[@]}" ; do
+                patch -p1 < "${patch}"
+            done
+
             ./contrib/download_prerequisites > prereq.log 2>&1
             GCCROOT=${PWD}
             mkdir obj
@@ -162,6 +172,9 @@ leak:blacs_gridmap_
 leak:PPEXSIDFTDriver
 # leaks in SuperLU
 leak:symbfact_distributeMatrix
+# leak due to compiler bug triggered by combination of OOP and ALLOCATABLE
+leak:__dbcsr_tensor_types_MOD___copy_dbcsr_tensor_types_Dbcsr_tas_dist_t
+leak:__dbcsr_tensor_types_MOD___copy_dbcsr_tensor_types_Dbcsr_tas_blk_size_t
 EOF
 cat << EOF >> ${INSTALLDIR}/tsan.supp
 # tsan bugs likely related to gcc
@@ -180,8 +193,7 @@ export LSAN_OPTIONS=suppressions=${INSTALLDIR}/lsan.supp
 export TSAN_OPTIONS=suppressions=${INSTALLDIR}/tsan.supp
 EOF
 
-# update toolchain environment
 load "${BUILDDIR}/setup_gcc"
-export -p > "${INSTALLDIR}/toolchain.env"
+write_toolchain_env "${INSTALLDIR}"
 
 report_timing "gcc"
