@@ -2,8 +2,10 @@
 [ "${BASH_SOURCE[0]}" ] && SCRIPT_NAME="${BASH_SOURCE[0]}" || SCRIPT_NAME=$0
 SCRIPT_DIR="$(cd "$(dirname "$SCRIPT_NAME")" && pwd -P)"
 
-mpich_ver="3.3"
-mpich_sha256="329ee02fe6c3d101b6b30a7b6fb97ddf6e82b28844306771fa9dd8845108fa0b"
+mpich_ver="3.3.2"
+mpich_sha256="4bfaf8837a54771d3e4922c84071ef80ffebddbb6971a006038d91ee7ef959b9"
+mpich_pkg="mpich-${mpich_ver}.tar.gz"
+
 source "${SCRIPT_DIR}"/common_vars.sh
 source "${SCRIPT_DIR}"/tool_kit.sh
 source "${SCRIPT_DIR}"/signal_trap.sh
@@ -27,19 +29,23 @@ case "$with_mpich" in
         if verify_checksums "${install_lock_file}" ; then
             echo "mpich-${mpich_ver} is already installed, skipping it."
         else
-            if [ -f mpich-${mpich_ver}.tar.gz ] ; then
-                echo "mpich-${mpich_ver}.tar.gz is found"
+            if [ -f ${mpich_pkg} ] ; then
+                echo "${mpich_pkg} is found"
             else
                 download_pkg ${DOWNLOADER_FLAGS} ${mpich_sha256}\
-                             https://www.cp2k.org/static/downloads/mpich-${mpich_ver}.tar.gz
+                             https://www.cp2k.org/static/downloads/${mpich_pkg}
             fi
             echo "Installing from scratch into ${pkg_install_dir}"
             [ -d mpich-${mpich_ver} ] && rm -rf mpich-${mpich_ver}
-            tar -xzf mpich-${mpich_ver}.tar.gz
+            tar -xzf ${mpich_pkg}
             cd mpich-${mpich_ver}
             unset F90
             unset F90FLAGS
-            ./configure --prefix="${pkg_install_dir}" --libdir="${pkg_install_dir}/lib" MPICC="" > configure.log 2>&1
+
+            # workaround for compilation with GCC-10, until properly fixed:
+            #   https://github.com/pmodels/mpich/issues/4300
+            ( "${FC}" --version | grep -Eq 'GNU.+\s10\.') && compat_flag="-fallow-argument-mismatch" || compat_flag=""
+            ./configure --prefix="${pkg_install_dir}" --libdir="${pkg_install_dir}/lib" MPICC="" FFLAGS="${FCFLAGS} ${compat_flag}" FCFLAGS="${FCFLAGS} ${compat_flag}" --without-x --enable-gl=no > configure.log 2>&1
             make -j $NPROCS > make.log 2>&1
             make install > install.log 2>&1
             cd ..
@@ -111,9 +117,8 @@ export CP_LIBS="\${CP_LIBS} IF_MPI(${MPICH_LIBS}|)"
 EOF
 fi
 
-# update toolchain environment
 load "${BUILDDIR}/setup_mpich"
-export -p > "${INSTALLDIR}/toolchain.env"
+write_toolchain_env "${INSTALLDIR}"
 
 cd "${ROOTDIR}"
 report_timing "mpich"
